(* Mathematica Init File *)

Print["Version: 1.1 ; Author: Renato Fonseca\nFor help, use the ", 
 Hyperlink["Susyno Tutorial", 
  "paclet:Susyno/tutorial/SusynoTutorial"], " and the built-in \
documentation."]


ClearAll["`*"];
Get[ "Susyno`LieGroups`"]
Get[ "Susyno`SusyRGEs`"]
Get[ "Susyno`Susyno`"]
